@@ -1,8 +1,12 @@
-from __future__ import print_function, absolute_import, unicode_literals
-from zope.interface import implementer
+from __future__ import absolute_import, print_function, unicode_literals
+
 import contextlib
+
+from zope.interface import implementer
+
 from ._interfaces import IJournal
 
+
 @implementer(IJournal)
 class Journal(object):
     def __init__(self, save_checkpoint):
@@ -19,7 +23,7 @@ class Journal(object):
         assert not self._processing
         assert not self._outbound_queue
         self._processing = True
-        yield # process inbound messages, change state, queue outbound
+        yield  # process inbound messages, change state, queue outbound
         self._save_checkpoint()
         for (fn, args, kwargs) in self._outbound_queue:
             fn(*args, **kwargs)
@@ -31,8 +35,10 @@ class Journal(object):
 class ImmediateJournal(object):
     def __init__(self):
         pass
+
     def queue_outbound(self, fn, *args, **kwargs):
         fn(*args, **kwargs)
+
     @contextlib.contextmanager
     def process(self):
         yield
